from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Float, String, Int, File

Seqkit_Stats_V0_1_0 = CommandToolBuilder(tool="seqkit_stats", base_command=["seqkit", "stats"], inputs=[ToolInput(tag="in_all", input_type=Boolean(optional=True), prefix="--all", doc=InputDocumentation(doc="all statistics, including quartiles of seq length, sum_gap, N50")), ToolInput(tag="in_basename", input_type=Boolean(optional=True), prefix="--basename", doc=InputDocumentation(doc="only output basename of files")), ToolInput(tag="in_fq_encoding", input_type=Float(optional=True), prefix="--fq-encoding", doc=InputDocumentation(doc="fastq quality encoding. available values: 'sanger', 'solexa', 'illumina-1.3+', 'illumina-1.5+', 'illumina-1.8+'. (default 'sanger')")), ToolInput(tag="in_gap_letters", input_type=String(optional=True), prefix="--gap-letters", doc=InputDocumentation(doc="gap letters (default '- .')")), ToolInput(tag="in_skip_err", input_type=Boolean(optional=True), prefix="--skip-err", doc=InputDocumentation(doc="skip error, only show warning message")), ToolInput(tag="in_stdin_label", input_type=String(optional=True), prefix="--stdin-label", doc=InputDocumentation(doc="label for replacing default '-' for stdin (default '-')")), ToolInput(tag="in_tabular", input_type=Boolean(optional=True), prefix="--tabular", doc=InputDocumentation(doc="output in machine-friendly tabular format")), ToolInput(tag="in_alphabet_guess_seq_length", input_type=Int(optional=True), prefix="--alphabet-guess-seq-length", doc=InputDocumentation(doc="length of sequence prefix of the first FASTA record based on which seqkit guesses the sequence type (0 for whole seq) (default 10000)")), ToolInput(tag="in_id_ncbi", input_type=Boolean(optional=True), prefix="--id-ncbi", doc=InputDocumentation(doc="FASTA head is NCBI-style, e.g. >gi|110645304|ref|NC_002516.2| Pseud...")), ToolInput(tag="in_id_regexp", input_type=String(optional=True), prefix="--id-regexp", doc=InputDocumentation(doc="regular expression for parsing ID (default '^(\\S+)\\s?')")), ToolInput(tag="in_in_file_list", input_type=File(optional=True), prefix="--infile-list", doc=InputDocumentation(doc="file of input files list (one file per line), if given, they are appended to files from cli arguments")), ToolInput(tag="in_line_width", input_type=Int(optional=True), prefix="--line-width", doc=InputDocumentation(doc="line width when outputing FASTA format (0 for no wrap) (default 60)")), ToolInput(tag="in_out_file", input_type=File(optional=True), prefix="--out-file", doc=InputDocumentation(doc="out file ('-' for stdout, suffix .gz for gzipped out) (default '-')")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="be quiet and do not show extra information")), ToolInput(tag="in_seq_type", input_type=String(optional=True), prefix="--seq-type", doc=InputDocumentation(doc="sequence type (dna|rna|protein|unlimit|auto) (for auto, it automatically detect by the first sequence) (default 'auto')")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="number of CPUs. (default value: 1 for single-CPU PC, 2 for others. can also set with environment variable SEQKIT_THREADS) (default 2)"))], outputs=[ToolOutput(tag="out_out_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_file", type_hint=File()), doc=OutputDocumentation(doc="out file ('-' for stdout, suffix .gz for gzipped out) (default '-')"))], container="quay.io/biocontainers/seqkit:0.16.0--h9ee0642_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Seqkit_Stats_V0_1_0().translate("wdl")

